@@ -1,7 +1,7 @@
-/* $Id: wl.h,v 1.4 2005/11/09 13:47:20 hacki Exp $ */
+/* $Id: wl.h,v 1.7 2006/05/04 18:44:47 hacki Exp $ */
 
 /*
- * Copyright (c) 2005 Marcus Glocker <marcus@nazgul.ch>
+ * Copyright (c) 2005, 2006 Marcus Glocker <marcus@nazgul.ch>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -16,12 +16,18 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
+#ifndef __OpenBSD__ 
+#define IFM_TYPE_MATCH(dt, t) (IFM_TYPE((dt)) == 0 || \
+    IFM_TYPE((dt)) == IFM_TYPE((t)))
+#endif
+
 /*
  * prototypes
  */
 int	get_wep(const char *);
 int	get_channel(const char *);
 int	get_signal(const char *, const char *);
+int 	get_wi_signal(const char *);
 int	check_nic(const char *);
 char *	get_speed(const char *);
 char *	get_status(const char *);
