@@ -1,7 +1,7 @@
-/* $Id: wmwlmon.c,v 1.33 2005/11/10 12:17:27 hacki Exp $ */
+/* $Id: wmwlmon.c,v 1.40 2006/05/10 04:00:34 hacki Exp $ */
 
 /*
- * Copyright (c) 2005 Marcus Glocker <marcus@nazgul.ch>
+ * Copyright (c) 2005, 2006 Marcus Glocker <marcus@nazgul.ch>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -16,6 +16,7 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
+#include <ctype.h>
 #include <err.h>
 #include <limits.h>
 #include <math.h>
@@ -59,7 +60,7 @@ int	scroll_fade(const int, const int, const int, const int, const int,
 /*
  * global variables for this file
  */
-static const char	*version = "0.8";
+static const char	*version = "0.9";
 volatile sig_atomic_t	quit = 0;
 char			TimeColor[30] = "#ffff00";
 char			BackgroundColor[30] = "#181818";
@@ -214,12 +215,13 @@ usage(int mode)
 	}
 
 	fprintf(stderr, "usage: %s ", __progname);
-	fprintf(stderr, "[-Dhv] [-i interface] [-s scrolling] ");
+	fprintf(stderr, "[-Dhvw] [-i interface] [-s scrolling] ");
 	fprintf(stderr, "[-display display]\n\n");
 	fprintf(stderr, "options:\n");
 	fprintf(stderr, "  -D\t\t: Debug mode.\n");
 	fprintf(stderr, "  -h\t\t: This help.\n");
 	fprintf(stderr, "  -v\t\t: Shows version.\n");
+	fprintf(stderr, "  -w\t\t: Enable WaveLAN compatibility.\n");
 	fprintf(stderr, "  -i\t\t: Set interface.\n");
 	fprintf(stderr, "  -s\t\t: Network ID scrolling.\n");
 	fprintf(stderr, "    \t\t  0 = Disable 1 = LCD (default) 2 = Bounce ");
@@ -271,14 +273,14 @@ signal_handler(const int sig)
 int
 main(int argc, char *argv[])
 {
-	int		i, r, ch;
-	int		opt_debug = 0, nic_status = 1;
-	long		opt_scroll = 1;
+	int		i, r, ch, opt_wavelan = 0;
+	int		opt_debug = 0, nic_status = 1, opt_scroll = 1;
 	char		*opt_interface = NULL, *opt_display = NULL;
-	char		*wnic = NULL, *nwid = NULL, *speed = NULL;
-	char		*status = NULL;
+	char		*nwid = NULL, *speed = NULL, *status = NULL;
 	char		sig[4], chn[4];
+#ifdef __OpenBSD__
 	const char	*errstr;
+#endif
 	XEvent		event;
 
 	/*
@@ -291,7 +293,7 @@ main(int argc, char *argv[])
 			argv[i] = "-d";
 	}
 
-	while ((ch = getopt(argc, argv, "Dd:hi:s:v")) != -1) {
+	while ((ch = getopt(argc, argv, "Dd:hi:s:vw")) != -1) {
 		switch (ch) {
 		case 'D':
 			opt_debug = 1;
@@ -303,13 +305,20 @@ main(int argc, char *argv[])
 			opt_interface = strdup(optarg);
 			break;
 		case 's':
+#ifdef __OpenBSD__
 			opt_scroll = strtonum(optarg, 0, 3, &errstr);
 			if (errstr)
 				usage(0);
+#else
+			opt_scroll = strtol(optarg, 0, 10);
+#endif
 			break;
 		case 'v':
 			usage(1);
 			break;
+		case 'w':
+			opt_wavelan = 1;
+			break;
 		case 'h':
 			/* FALLTHROUGH */
 		default:
@@ -323,12 +332,11 @@ main(int argc, char *argv[])
 	 */
 	if (opt_interface == NULL) {
 		/* scan for interface */
-		wnic = get_first_wnic();
-		if (wnic == NULL) {
+		opt_interface = get_first_wnic();
+		if (opt_interface == NULL) {
 			fprintf(stderr, "No wireless interface found\n"); 
 			exit(1);
 		}
-		opt_interface = wnic;
 	} else {
 		/* check defined interface */
 		if (!check_nic(opt_interface)) {
@@ -344,6 +352,9 @@ main(int argc, char *argv[])
 			}
 		}
 	}
+	/* is the interface wi? */
+	if ((strncmp(opt_interface, "wi", 2) == 0) && isdigit(opt_interface[2]))
+		opt_wavelan = 1;
 
 	/*
 	 * install signal handler
@@ -414,7 +425,11 @@ main(int argc, char *argv[])
 			}
 
 			/* signal strength */
-			r = get_signal(opt_interface, nwid);
+			if (opt_wavelan)
+				r = get_wi_signal(opt_interface);
+			else
+				r = get_signal(opt_interface, nwid);
+
 			if (r > 0) {
 				copyXPMArea(15, 67, 10, 6, 30, 29);
 				snprintf(sig, sizeof(sig), "%d", r);
@@ -579,7 +594,7 @@ draw_string(const char *string, const int x, const int y)
 {
 	int	c, i, offset;
 
-	for (i = 0, offset = x; string[i] != NULL; i++) {
+	for (i = 0, offset = x; string[i] != '\0'; i++) {
 		c = string[i];
 
 		copyXPMArea(fonts[c].x, fonts[c].y, fonts[c].w, fonts[c].h,
@@ -650,7 +665,7 @@ scroll_lcd(const int src_x, const int src_y, const int dst_x,
 	/* move to next pixel */
 	pos++;
 
-	return pos;
+	return (pos);
 }
 
 /*
@@ -686,7 +701,7 @@ scroll_bounce(const int src_x, const int src_y, const int dst_x,
 			copyXPMArea(pos + 1, src_y, NWIDLENP, 8, dst_x, dst_y);
 		delay--;
 
-		return pos;
+		return (pos);
 	}
 
 	/* start */
@@ -710,7 +725,7 @@ scroll_bounce(const int src_x, const int src_y, const int dst_x,
 	if (direction == 1)
 		pos--;
 
-	return pos;
+	return (pos);
 }
 
 /*
@@ -743,7 +758,7 @@ scroll_fade(const int src_x, const int src_y, const int dst_x,
 		copyXPMArea(pos - 1, src_y, NWIDLENP, 8, dst_x, dst_y);
 		delay--;
 
-		return pos;
+		return (pos);
 	}
 
 	/* end */
@@ -763,5 +778,5 @@ scroll_fade(const int src_x, const int src_y, const int dst_x,
 	/* move to next pixel */
 	pos++;
 
-	return pos;
+	return (pos);
 }
